
Event Dispatcher
----------------

The IoC package includes a small event dispatcher, you can include it by adding this yaml.

Configuration
~~~~~~~~~~~~~

.. code-block:: yaml

    ioc.extra.event:
